Index: /trunk/src/VBox/Main/HostImpl.cpp
===================================================================
--- /trunk/src/VBox/Main/HostImpl.cpp	(revision 32931)
+++ /trunk/src/VBox/Main/HostImpl.cpp	(revision 32932)
@@ -2006,10 +2006,10 @@
 
     /*
      * Check for removable media instead of "SCSI" so that we also include USB CD-ROMs.
      * As unfortunately the Solaris drivers only export these common properties.
      */
     int *pInt = NULL;
-    if (   di_prop_lookup_ints(DDI_DEV_T_ANY, Node, "removable-media", &pInt) > 0
-        && *pInt == 1)                                                                  /* Removable Media */
+    if (   di_prop_lookup_ints(DDI_DEV_T_ANY, Node, "removable-media", &pInt) >= 0
+        || di_prop_lookup_ints(DDI_DEV_T_ANY, Node, "hotpluggable", &pInt) >= 0)
     {
         if (di_prop_lookup_ints(DDI_DEV_T_ANY, Node, "inquiry-device-type", &pInt) > 0
@@ -2006,10 +2006,10 @@
 
     /*
-     * Check for removable media instead of "SCSI" so that we also include USB CD-ROMs.
+     * Check for "removable-media" or "hotpluggable" instead of "SCSI" so that we also include USB CD-ROMs.
      * As unfortunately the Solaris drivers only export these common properties.
      */
